跳到主要内容

OwnedNotified

搜索

结构体 OwnedNotified 

源代码
pub struct OwnedNotified { /* 私有字段 */ }
展开描述

Notify::notified_owned() 返回的 Future。

此 future 是 fused 的,因此一旦它完成,后续任何对 poll 的调用都会立即返回 Poll::Ready

实现

源代码

impl OwnedNotified

源代码

pub fn enable(self: Pin<&mut Self>) -> bool

将此 future 添加到已准备好通过调用 notify_one 接收唤醒的 future 列表中。

有关更多详细信息,请参阅 Notified::enable

trait 实现

源代码

impl Debug for OwnedNotified

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl Drop for OwnedNotified

源代码

fn drop(&mut self)

执行此类型的析构函数。 更多信息
源代码

impl Future for OwnedNotified

源代码

type Output = ()

Future 完成时产生的值的类型。
源代码

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<()>

Attempts to resolve the future to a final value, registering the current task for wakeup if the value is not yet available. 更多信息
源代码

impl Sync for OwnedNotified

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换是 From<T> for U 实现选择执行的操作。

源代码

impl<F> IntoFuture for F
where F: Future,

源代码

type Output = <F as Future>::Output

Future 完成时产生的输出。
源代码

type IntoFuture = F

我们将要把此值转变成哪种 future?
源代码

fn into_future(self) -> <F as IntoFuture>::IntoFuture

Creates a future from a value. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。